==> haskell-quickcheck-instances-0.3.19-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.19
id: quickcheck-instances-0.3.19-HL3mEIKlsBN8FaZYESGDol
key: quickcheck-instances-0.3.19-HL3mEIKlsBN8FaZYESGDol
license: BSD-3-Clause
copyright: Copyright Antoine Latter, 2012-2014
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
abi: e3c3894ed372d74972a0ac5dafc05595
exposed: True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup
    Test.QuickCheck.Instances.Tagged Test.QuickCheck.Instances.Text
    Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector
import-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-instances-0.3.19
library-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-instances-0.3.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/quickcheck-instances-0.3.19
hs-libraries: HSquickcheck-instances-0.3.19-HL3mEIKlsBN8FaZYESGDol
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 array-0.5.3.0
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.19-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.19
id: quickcheck-instances-0.3.19-DkbwbtagYhbDo5fzLZ5DV1
key: quickcheck-instances-0.3.19-DkbwbtagYhbDo5fzLZ5DV1
license: BSD-3-Clause
copyright: Copyright Antoine Latter, 2012-2014
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
abi: d82bb832048261e686f247eff434e7a0
exposed: True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup
    Test.QuickCheck.Instances.Tagged Test.QuickCheck.Instances.Text
    Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector
import-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-instances-0.3.19
library-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-instances-0.3.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/quickcheck-instances-0.3.19
hs-libraries: HSquickcheck-instances-0.3.19-DkbwbtagYhbDo5fzLZ5DV1
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 array-0.5.3.0
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
